@@ -20,7 +20,8 @@ class colormanager : public config_action_handler {
 		colormanager();
 		~colormanager();
 		void register_commands(configparser& cfgparser);
-		virtual action_handler_status handle_action(const std::string& action, const std::vector<std::string>& params);
+		virtual void handle_action(const std::string& action, const std::vector<std::string>& params);
+		virtual void dump_config(std::vector<std::string>& config_output);
 		inline bool colors_loaded() { return colors_loaded_; }
 		void set_pb_colors(podbeuter::pb_view * v);
 		inline std::map<std::string,std::string>& get_fgcolors() { return fg_colors; }
