@@ -19,6 +19,8 @@ namespace newsbeuter {
 			matcher(const std::string& expr);
 			bool parse(const std::string& expr);
 			bool matches(matchable* item);
+			const std::string& get_parse_error();
+			const std::string& get_expression();
 		private:
 			bool matches_r(expression * e, matchable * item);
 
@@ -27,9 +29,12 @@ namespace newsbeuter {
 			bool matchop_rxeq(expression * e, matchable * item);
 			bool matchop_cont(expression * e, matchable * item);
 			bool matchop_eq(expression * e, matchable * item);
+			bool matchop_between(expression * e, matchable * item);
 
 			FilterParser p;
 			bool success;
+			std::string errmsg;
+			std::string exp;
 	};
 
 }
