@@ -11,15 +11,13 @@ namespace podbeuter {
 
 class pb_controller;
 
-class newsbeuter::colormanager;
-
 struct keymap_hint_entry;
 
 class pb_view {
 	public:
 		pb_view(pb_controller * c = 0);
 		~pb_view();
-		void run();
+		void run(bool auto_download);
 		void set_keymap(newsbeuter::keymap * k) { 
 			keys = k; 
 			set_bindings();
