@@ -75,6 +75,10 @@ namespace newsbeuter {
 			bool get_next_feed(itemlist_formaction * itemlist);
 			bool get_prev_feed(itemlist_formaction * itemlist);
 
+			void prepare_query_feed(std::tr1::shared_ptr<rss_feed> feed);
+
+			void force_redraw();
+
 			void set_colors(std::map<std::string,std::string>& fg_colors, std::map<std::string,std::string>& bg_colors, std::map<std::string,std::vector<std::string> >& attributes);
 
 			void notify_itemlist_change(std::tr1::shared_ptr<rss_feed> feed);
