@@ -1,4 +1,4 @@
-/* rsspp - Copyright (C) 2008-2011 Andreas Krennmair <ak@newsbeuter.org>
+/* rsspp - Copyright (C) 2008-2012 Andreas Krennmair <ak@newsbeuter.org>
  * Licensed under the MIT/X Consortium License. See file LICENSE
  * for more information.
  */
@@ -75,10 +75,10 @@ item rss_09x_parser::parse_item(xmlNode * itemNode) {
 			it.itunes_summary = get_content(node);
 		} else if (node_is(node, "guid", ns)) {
 			it.guid = get_content(node);
-			it.guid_isPermaLink = false;
+			it.guid_isPermaLink = true;
 			std::string isPermaLink = get_prop(node,"isPermaLink");
-			if (isPermaLink == "true")
-				it.guid_isPermaLink = true;
+			if (isPermaLink == "false")
+				it.guid_isPermaLink = false;
 		} else if (node_is(node, "pubDate", ns)) {
 			it.pubDate = get_content(node);
 		} else if (node_is(node, "date", DC_URI)) {
