@@ -94,7 +94,7 @@ void dialogs_formaction::handle_cmdline(const std::string& cmd) {
 	unsigned int idx = 0;
 	if (1==sscanf(cmd.c_str(), "%u", &idx)) {
 		if (idx <= v->formaction_stack_size()) {
-			f->set("dialogpos", utils::to_s(idx - 1));
+			f->set("dialogpos", utils::to_string<unsigned int>(idx - 1));
 		} else {
 			v->show_error(_("Invalid position!"));
 		}
