@@ -17,6 +17,14 @@ formaction::formaction(view * vv, std::string formstr) : v(vv), f(new stfl::form
 		if (v->get_cfg()->get_configvalue_as_bool("show-keymap-hint") == false) {
 			f->set("showhint", "0");
 		}
+		if (v->get_cfg()->get_configvalue_as_bool("swap-title-and-hints") == true) {
+			std::string hints = f->dump("hints", "", 0);
+			std::string title = f->dump("title", "", 0);
+			f->modify("title", "replace", "label[swap-title]");
+			f->modify("hints", "replace", "label[swap-hints]");
+			f->modify("swap-title", "replace", hints);
+			f->modify("swap-hints", "replace", title);
+		}
 	}
 	valid_cmds.push_back("set");
 	valid_cmds.push_back("quit");
@@ -101,14 +109,14 @@ void formaction::process_op(operation op, bool automatic, std::vector<std::strin
 			if (qna_history) {
 				std::string entry = qna_history->next();
 				f->set("qna_value", entry);
-				f->set("qna_value_pos", utils::to_s(entry.length()));
+				f->set("qna_value_pos", utils::to_string<unsigned int>(entry.length()));
 			}
 			break;
 		case OP_INT_QNA_PREVHIST:
 			if (qna_history) {
 				std::string entry = qna_history->prev();
 				f->set("qna_value", entry);
-				f->set("qna_value_pos", utils::to_s(entry.length()));
+				f->set("qna_value_pos", utils::to_string<unsigned int>(entry.length()));
 			}
 			break;
 		case OP_INT_END_QUESTION:
@@ -363,7 +371,7 @@ void formaction::start_next_question() {
 		replacestr.append("}{input[qnainput] on_ESC:cancel-qna on_UP:qna-prev-history on_DOWN:qna-next-history on_ENTER:end-question modal:1 .expand:h @bind_home:** @bind_end:** text[qna_value]:");
 		replacestr.append(stfl::quote(qna_prompts[0].second));
 		replacestr.append(" pos[qna_value_pos]:");
-		replacestr.append(utils::to_s(qna_prompts[0].second.length()));
+		replacestr.append(utils::to_string<unsigned int>(qna_prompts[0].second.length()));
 		replacestr.append("}}");
 		qna_prompts.erase(qna_prompts.begin());
 		f->modify("lastline", "replace", replacestr);
