@@ -21,6 +21,7 @@ htmlrenderer::htmlrenderer(unsigned int width, bool raw) : w(width), raw_(raw) {
 	tags["ituneshack"] = TAG_ITUNESHACK;
 	tags["img"] = TAG_IMG;
 	tags["blockquote"] = TAG_BLOCKQUOTE;
+	tags["aside"] = TAG_BLOCKQUOTE;
 	tags["p"] = TAG_P;
 	tags["h1"] = TAG_H1;
 	tags["h2"] = TAG_H2;
@@ -38,6 +39,7 @@ htmlrenderer::htmlrenderer(unsigned int width, bool raw) : w(width), raw_(raw) {
 	tags["b"] = TAG_STRONG;
 	tags["strong"] = TAG_STRONG;
 	tags["u"] = TAG_UNDERLINE;
+	tags["q"] = TAG_QUOTATION;
 	tags["script"] = TAG_SCRIPT;
 	tags["style"] = TAG_STYLE;
 	tags["table"] = TAG_TABLE;
@@ -71,7 +73,7 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 	unsigned int image_count = 0;
 	std::string curline;
 	int indent_level = 0;
-	bool inside_list = false, inside_li = false, is_ol = false, inside_pre = false;
+	bool inside_li = false, is_ol = false, inside_pre = false;
 	bool itunes_hack = false;
 	size_t inside_script = 0;
 	size_t inside_style = 0;
@@ -117,13 +119,17 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 						}
 						break;
 					case TAG_STRONG:
-						if (!raw_) 
+						if (!raw_)
 							curline.append("<b>");
 						break;
 					case TAG_UNDERLINE:
-						if (!raw_) 
+						if (!raw_)
 							curline.append("<u>");
 						break;
+					case TAG_QUOTATION:
+						if (!raw_)
+							curline.append("\"");
+						break;
 
 					case TAG_EMBED: {
 							std::string type;
@@ -199,7 +205,6 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 						break;
 
 					case TAG_OL:
-						inside_list = true;
 						is_ol = true;
 						{
 							unsigned int ol_count = 1;
@@ -229,7 +234,6 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 						break;
 
 					case TAG_UL:
-						inside_list = true;
 						is_ol = false;
 						add_nonempty_line(curline, tables, lines);
 						add_line("", tables, lines);
@@ -317,7 +321,19 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 							tables.back().start_row();
 						break;
 
-					case TAG_TH:
+					case TAG_TH: {
+						size_t span = 1;
+						try {
+							span = utils::to_u(xpp.getAttributeValue("colspan"));
+						} catch (const std::invalid_argument& ) {
+							// is ok, span 1 than
+						}
+						if (!tables.empty())
+							tables.back().start_cell(span);
+							curline.append("<b>");
+						break;
+					}
+
 					case TAG_TD: {
 						size_t span = 1;
 						try {
@@ -354,7 +370,6 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 						ol_counts.pop_back();
 						// fall-through
 					case TAG_UL:
-						inside_list = false;
 						if (inside_li) {
 							indent_level-=2;
 							if (indent_level < 0) indent_level = 0;
@@ -443,6 +458,11 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 							curline.append("</>");
 						break;
 
+					case TAG_QUOTATION:
+						if (!raw_)
+							curline.append("\"");
+						break;
+
 					case TAG_EMBED:
 					case TAG_BR:
 					case TAG_ITUNESHACK:
@@ -499,6 +519,14 @@ void htmlrenderer::render(std::istream& input, std::vector<std::string>& lines,
 						break;
 
 					case TAG_TH:
+						add_nonempty_line(curline, tables, lines);
+						prepare_newline(curline, 0); // no indent in tables
+
+						if (!tables.empty())
+							curline.append("</>");
+							tables.back().complete_cell();
+						break;
+
 					case TAG_TD:
 						add_nonempty_line(curline, tables, lines);
 						prepare_newline(curline, 0); // no indent in tables
