@@ -31,7 +31,7 @@ void itemview_formaction::init() {
 	if (!v->get_cfg()->get_configvalue_as_bool("display-article-progress")) {
 		f->set("percentwidth", "0");
 	} else {
-		f->set("percentwidth", utils::to_s(utils::max(6, utils::max(strlen(_("Top")), strlen(_("Bottom"))))));
+		f->set("percentwidth", utils::to_string<unsigned int>(utils::max(6, utils::max(strlen(_("Top")), strlen(_("Bottom"))))));
 		update_percent();
 	}
 	set_keymap_hints();
@@ -114,7 +114,11 @@ void itemview_formaction::prepare() {
 
 		listfmt.add_line("");
 
-		set_head(item->title());
+		unsigned int unread_item_count = feed->unread_item_count();
+		// we need to subtract because the current item isn't yet marked as read
+		if (item->unread())
+			unread_item_count--;
+		set_head(item->title(), unread_item_count, feed->items().size());
 
 		unsigned int textwidth = v->get_cfg()->get_configvalue_as_int("text-width");
 		if (textwidth > 0) {
@@ -212,8 +216,8 @@ void itemview_formaction::process_operation(operation op, bool automatic, std::v
 		case OP_BOOKMARK:
 			if (automatic) {
 				qna_responses.clear();
-				qna_responses.push_back(item->title());
 				qna_responses.push_back(item->link());
+				qna_responses.push_back(item->title());
 				qna_responses.push_back(args->size() > 0 ? (*args)[0] : "");
 			} else {
 				this->start_bookmark_qna(item->title(), item->link(), "");
@@ -409,12 +413,15 @@ keymap_hint_entry * itemview_formaction::get_keymap_hint() {
 	return hints;
 }
 
-void itemview_formaction::set_head(const std::string& s) {
+void itemview_formaction::set_head(const std::string& s, unsigned int unread, unsigned int total) {
 	fmtstr_formatter fmt;
 	fmt.register_fmt('N', PROGRAM_NAME);
 	fmt.register_fmt('V', PROGRAM_VERSION);
 	fmt.register_fmt('T', s);
 
+	fmt.register_fmt('u', utils::to_string(unread));
+	fmt.register_fmt('t', utils::to_string(total));
+
 	std::string listwidth = f->get("article:w");
 	std::istringstream is(listwidth);
 	unsigned int width;
