@@ -22,8 +22,8 @@ thread::~thread() {
 }
 
 pthread_t thread::start() {
-	int rc = pthread_create(&pt, 0, (void *(*)(void*))run_thread, this);
-	GetLogger().log(LOG_DEBUG, "thread::start: created new thread %d rc = %d", pt, rc);
+	int rc = pthread_create(&pt, 0, run_thread, this);
+	LOG(LOG_DEBUG, "thread::start: created new thread %d rc = %d", pt, rc);
 	if (rc != 0) {
 		throw exception(rc);
 	}
@@ -35,13 +35,13 @@ void thread::join() {
 }
 
 void thread::detach() {
-	GetLogger().log(LOG_DEBUG, "thread::detach: detaching thread %d", pt);
+	LOG(LOG_DEBUG, "thread::detach: detaching thread %d", pt);
 	pthread_detach(pt);
 }
 
-void * run_thread(thread * p) {
-	thread * t = p;
-	GetLogger().log(LOG_DEBUG, "run_thread: p = %p", p);
+void * run_thread(void * p) {
+	thread * t = reinterpret_cast<thread *>(p);
+	LOG(LOG_DEBUG, "run_thread: p = %p", p);
 	t->run();
 	delete t;
 	return 0;
